@@ -1,4 +1,4 @@
 {-# LANGUAGE CPP #-}
 #define PLATFORM_NAME   Posix
-#define IS_WINDOWS      False
+#define IS_WINDOWS      0
 #include "Include.hs"
