@@ -1,4 +1,4 @@
 {-# LANGUAGE CPP #-}
 #define PLATFORM_NAME   Windows
-#define IS_WINDOWS      True
+#define IS_WINDOWS      1
 #include "Include.hs"
